/*   HEADER   */

.section-notheme #top-actions,
#top-actions {
    background: #3b3a3a none repeat scroll 0 0;
    padding: 0.25em 0;
}

#portal-personaltools dd {
    background-color: #3b3a3a;
}

#portal-personaltools dd a:hover {
    background: #4e4e4e;
}

.nav-is-stuck #top-actions  {
    padding: 0;
    transition: padding 1s ease 0s, font-size 1s ease 0s;
    font-size: 90%;
}
[id="top-menu-actions"]{
    float: left;
}
.top-menu-action {
    display: inline-block;
    vertical-align: top;
    font-size: 85%;
}
/*   NAVIGATION   */

#top-navigation-inner::after{
    display:none;
}

#top-navigation-inner{
    display: block;
    padding-top: 0.5%;
    max-width: 1400px;
}

#top-logo,
#top-navigation-inner #navWrapper{
    display: block;
    float: left;
}

/*   MINI SITE   */
#portal-header{
    z-index: 3;
}
#container-minisite-globalnav {
    z-index: 2;
}
#container-minisite-globalnav .minisite-dropdown-menu > ul > li > ul {
    display: none;
}
#minisite-navigation-inner .minisite-dropdown-menu > ul > li > ul.normal-sub {
    width: 300px;
}
#portal-top #cpskin-banner {
    z-index: 1;
}
/*   site action   */

.in-minisite-out-portal #top-actions{
    display: none;
}

.in-minisite-out-portal .bloc-item,
.in-minisite-in-portal .bloc-item{
    width: 21.8%;
}